.. highlight:: shell

============
Installation
============


From source (recommended)
------------

VFormer can be installed from the `GitHub repo`_.

Clone the public repository:

.. code-block:: console

    $ git clone https://github.com/SforAiDl/vformer.git

and then run the following command to install VFormer:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/SforAiDl/vformer


Stable release
--------------

To install VFormer, run this command in your terminal:

.. code-block:: console

    $ pip install vformer

Note that VFormer is an active project and routinely publishes new releases. In order to upgrade VFormer to the latest version, use pip as follows:

.. code-block:: console

    $ pip install -U vformer